"""
.. include:: ../README.md
.. include:: ../CHANGELOG.md
"""

from crypticorn.common.logging import configure_logging
configure_logging("crypticorn")

from crypticorn.client import ApiClient

__all__ = ["ApiClient"]




from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from crypticorn.common.logging import configure_logging
import logging


def add_cors_middleware(app: "FastAPI"):
    app.add_middleware(
        CORSMiddleware,
        allow_origins=[
            "http://localhost:5173", # vite dev server
            "http://localhost:4173", # vite preview server
        ],
        allow_origin_regex="^https:\/\/([a-zA-Z0-9-]+\.)*crypticorn\.(dev|com)\/?$", # matches (multiple or no) subdomains of crypticorn.dev and crypticorn.com
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )

async def default_lifespan(app: FastAPI):
    """Default lifespan for the applications.
    This is used to configure the logging for the application.
    To override this, pass a different lifespan to the FastAPI constructor or call this lifespan within a custom lifespan.
    """
    configure_logging(__name__) # for the consuming app
    logger = logging.getLogger(__name__)
    yield



# coding: utf-8

"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Target(str, Enum):
    """
    All existing targets. Some might no be available in the latest data version, but kept for older versions.
    """

    """
    allowed enum values
    """
    TATOOINE = "Tatooine"
    ALDERAAN = "Alderaan"
    HOTH = "Hoth"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Target from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TimeInterval(str, Enum):
    """
    TimeInterval
    """

    """
    allowed enum values
    """
    ENUM_15M = "15m"
    ENUM_30M = "30m"
    ENUM_1H = "1h"
    ENUM_4H = "4h"
    ENUM_1D = "1d"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TimeInterval from a JSON string"""
        return cls(json.loads(json_str))
